@@ -19,7 +19,7 @@ class XeusClingKernelTests(jkt.KernelTests):
         try:
             cls.km, cls.kc = jkt.start_new_kernel(kernel_name=cls.kernel_name)
         except NoSuchKernel:
-            raise unittest.SkipTest("Xeus-Cling Kernel not installed")
+            raise unittest.SkipTest("Xeus-Cling Kernel not installed") from None
 
     language_name = "c++"
 
